@@ -5,7 +5,7 @@
 (set-author "Dietrich Radel")
 
 (set-start-position 234.5 232.5)
-(add-goal 221 226 #t "")
+(add-goal 221 226 #t "ki5")
 
 ;;; how much time each difficulty level gets
 (cond
