@@ -482,6 +482,8 @@ void Ball::tick(Real time) {
   int i;
   double phase;
 
+  Animated::tick(time);
+
   for(i=0;i<NUM_MODS;i++) {
 	if(!modTimeLeft[i]) modTimePhaseIn[i]=0.0;
 	else modTimePhaseIn[i]+=time;
@@ -1222,3 +1224,6 @@ void Ball::handlePipes() {
 	}
   }
 }
+
+void Ball::die(int how) { Animated::die(how); } 
+
