@@ -53,6 +53,9 @@ Bird::Bird(int x,int y,int dx,int dy,Real size,Real speed) {
   secondaryColor[2] = 0.9;
   animation=0.0;
   rotation=M_PI-atan2(this->dx/lng,this->dy/lng);
+
+  scoreOnDeath = Game::defaultScores[SCORE_BIRD][0];
+  timeOnDeath = Game::defaultScores[SCORE_BIRD][1];
 }
 
 void Bird::draw2() {
@@ -121,6 +124,7 @@ void Bird::draw2() {
 }
 
 void Bird::tick(Real t) {
+  Animated::tick(t);
 
   animation = fmod(animation+t/0.8,1.0);
 
@@ -152,16 +156,18 @@ void Bird::tick(Real t) {
     // TODO: improve the collision detection
     if(length(diff) < ball->radius + size*.75)   {
           if (ball->modTimeLeft[MOD_SPIKE])   {
-		  // the ball kills the bird !!!
-		  position[2] += 1.2;
-		  new ScoreSign(25,position);
-		  playEffect(SFX_BIRD_DIE);
-		  // restart the bird
-		  position[0] = x;
-		  position[1] = y;
-		  position[2] = Game::current->map->getHeight(position[0],position[1]) + .5;
-		  hide = 1.;
-		  return;
+	    // the ball kills the bird !!!
+	    Animated::die(DIE_OTHER);
+	    /*position[2] += 1.2;
+	      new ScoreSign(25,position);*/
+
+	    playEffect(SFX_BIRD_DIE);
+	    // restart the bird
+	    position[0] = x;
+	    position[1] = y;
+	    position[2] = Game::current->map->getHeight(position[0],position[1]) + .5;
+	    hide = 1.;
+	    return;
 	  }
 	  // kill the ball
 	  ball->die(DIE_CRASH);
