@@ -55,6 +55,7 @@ ColorModifier::ColorModifier(int col, int x, int y, Real min, Real max, Real fre
   secondaryColor[0] = 1.;
   secondaryColor[1] = 1.;
   secondaryColor[2] = 1.;
+  is_on=1;
 }
 
 void ColorModifier::draw() {
@@ -64,7 +65,8 @@ void ColorModifier::tick(Real t) {
   int i;
   double tt=Game::current->gameTime;
   Cell& c=Game::current->map->cell(x,y);
-  float v = min + (max-min)*(1. + cos(phase+(tt*freq)*2.*3.14159)) / 2.;
+  if(!is_on) return;
+  float v = min + (max-min)*(1. + cos(phase+(tt*freq)*2.*3.14159)) / 2.;  
   switch(colors)
     {
     case 0:
