@@ -27,6 +27,7 @@
 #include "player.h"
 #include "sound.h"
 #include "diamond.h"
+#include "sign.h"
 
 using namespace std;
 
@@ -103,4 +104,9 @@ void Diamond::onGet() {
   assign(position,Game::current->map->startPosition);
   playEffect(SFX_GOT_FLAG);
   fade=-14.0;
+
+  Coord3d signPos;
+  assign(position,signPos);
+  signPos[2] += 1.0;
+  new Sign("Save point",6.0,1.0,60.0,signPos);
 }
