@@ -105,7 +105,7 @@ enum { subFlagsIce=30, subFlagsAcid=31, subFlagsSand=32, subFlagsKill=33, subFla
 	   subFlagsNoGrid=35, subFlagsTrack=36, } subFlags;
 enum { subTexturesNext=40, subTexturesPrev, subTexturesRotate };
 
-enum { editModeHeight=0, editModeColor, editModeWater, editModeVelocity, editModeNoLines, nEditModes };
+enum { editModeHeight=0, editModeColor, editModeWater, editModeVelocity, editModeNoLines, editModeFeatures, nEditModes };
 
 /* These are all the codes for different areas of the screen that can be selected */
 #define CODE_FROM_COMMAND(x) (10+(x))
@@ -137,8 +137,10 @@ void EditMode::init() {
   memcpy(cMenuNames,cMenuNames_i18n,sizeof(cMenuNames));
 
   char *cMenuEntries_i18n[N_SUBMENUS][MAX_MENU_ENTRIES]={
-    /* TRANSLATORS: This is a list of all the submenus in the map editor, if the initial character is * or / it must be perserved as it is. */
-	{_("New"), _("Open"), _("Close"), _("Save"), _("Exit"), _("Test level"), NULL}, 
+    /* TRANSLATORS: This is a list of all the submenus in the map
+       editor, if the initial character is * or / then that character
+       must be perserved as it is. */
+	{_("New"), _("Open..."), _("Close"), _("Save"), _("Exit"), _("Test level"), NULL}, 
 	{_("Edit height"),_("Edit color"),_("Edit water"),_("Edit velocity"),_("Edit lines"),
 	 _("*<SPACE> Whole cell"), _("Upper corner"), _("Bottom corner"),_("Right corner"),_("Left corner"), _("Center"),
 	 _("Raise increment"),_("Lower increment"),_("*<SHIFT> reversed"),_("*<CTRL> walls"),NULL},
@@ -276,7 +278,7 @@ void EditMode::saveMap() {
 
   snprintf(mapname,sizeof(mapname)-1,"%s/.trackballs/levels/%s.map",getenv("HOME"),levelname);
   if(pathIsLink(str)) {
-	fprintf(stderr,_("Error, %s/.trackballs/levels%s.map is a symbolic link. Cannot save map\n"),getenv("HOME"),levelname);
+	fprintf(stderr,_("Error, %s/.trackballs/levels/%s.map is a symbolic link. Cannot save map\n"),getenv("HOME"),levelname);
 	return;
   }
   //snprintf(mapname,sizeof(mapname)-1,"%s/levels/%s.map",SHARE_DIR,name); only if we allow saving in the share dir
@@ -359,19 +361,38 @@ void EditMode::display() {
   /* Draw the map and the current mapcursor/selected region */
   int x0,y0;
   if(map) {
-	map->draw(switchViewpoint|birdsEye,0,x,y);
-	map->draw(switchViewpoint|birdsEye,1,x,y);
-	/* If we have a clipboard selection then display where it will be pasted */
-	if(cellClipboard) {
-	  for(x0=x;x0<x+cellClipboardWidth;x0++)	  
-		for(y0=y;y0<y+cellClipboardHeight;y0++)
-		  map->drawFootprint(x0,y0,1);
-	} else if(markX >= 0) {
-	  /* Otherwise, if we have a marked region then display footprint over it */
-	  for(x0=min(markX,x);x0<=max(markX,x);x0++)
-		for(y0=min(markY,y);y0<=max(markY,y);y0++)
-		  map->drawFootprint(x0,y0,0);
-	} else map->drawFootprint(x,y,0);
+    map->draw(switchViewpoint|birdsEye,0,x,y);
+    map->draw(switchViewpoint|birdsEye,1,x,y);
+    /* If we have a clipboard selection then display where it will be pasted */
+    if(cellClipboard) {
+      for(x0=x;x0<x+cellClipboardWidth;x0++)	  
+	for(y0=y;y0<y+cellClipboardHeight;y0++)
+	  map->drawFootprint(x0,y0,1);
+    } else if(markX >= 0) {
+      /* Otherwise, if we have a marked region then display footprint over it */
+      for(x0=min(markX,x);x0<=max(markX,x);x0++)
+	for(y0=min(markY,y);y0<=max(markY,y);y0++)
+	  map->drawFootprint(x0,y0,0);
+    } else if(currentEditMode == editModeFeatures) {
+      /* We have currently in the "features" edit mode, display foot
+	 print of selected feature */
+      int footprintX, footprintY;
+      switch(currentFeature) {
+      case FEATURE_SPIKE: footprintX=2; footprintY=2; break;
+      case FEATURE_SMALL_HILL: footprintX=3; footprintY=3; break;
+      case FEATURE_MEDIUM_HILL: footprintX=5; footprintY=5; break;
+      case FEATURE_LARGE_HILL: footprintX=7; footprintY=7; break;
+      case FEATURE_HUGE_HILL: footprintX=11; footprintY=11; break;
+      case FEATURE_SMALL_SMOOTH: footprintX=5; footprintY=5; break;
+      case FEATURE_LARGE_SMOOTH: footprintX=11; footprintY=11; break;
+      default: footprintX=1; footprintY=1; 
+      }
+      for(x0=x-footprintX/2;x0<x+(footprintX+1)/2;x0++)
+	for(y0=y-footprintY/2;y0<y+(footprintY+1)/2;y0++) 
+	  map->drawFootprint(x0,y0,0);
+    }
+    /* Finally, if no other case then just draw position of cursor */
+    else map->drawFootprint(x,y,0);
   }
 
   /*
@@ -556,9 +577,16 @@ void EditMode::doCommand(int command) {
 	}
 	break;
 
-  case FEATURE_SMALL_HILL: /* ... */
-	/* TODO. Not implemented yet */
-	break;
+  case FEATURE_SPIKE:
+  case FEATURE_SMALL_HILL:
+  case FEATURE_MEDIUM_HILL:
+  case FEATURE_LARGE_HILL:
+  case FEATURE_HUGE_HILL:
+  case FEATURE_SMALL_SMOOTH:
+  case FEATURE_LARGE_SMOOTH:
+    currentEditMode=editModeFeatures;
+    currentFeature=command;
+    break;
 
   case MOVE_UP: x+=(switchViewpoint?-1:1)*(shift?5:1); break;
   case MOVE_DOWN: x-=(switchViewpoint?-1:1)*(shift?5:1); break;
@@ -584,7 +612,7 @@ void EditMode::doCommand(int command) {
 
   default:
 	/* TODO. Not implemented yet? */
-	printf("Command %d not yet implemented\n");
+	printf("Command %d not yet implemented\n",command);
 	break;
   }
 }
@@ -683,19 +711,60 @@ void EditMode::doCellAction(int code,int direction) {
 	break;
 
   case editModeNoLines: {
-	int flag=0;
-	if(code == CODE_CELL_N) flag=CELL_NOLINENORTH;
-	if(code == CODE_CELL_S) flag=CELL_NOLINESOUTH;
-	if(code == CODE_CELL_E) flag=CELL_NOLINEEAST;
-	if(code == CODE_CELL_W) flag=CELL_NOLINEWEST;
-	int onoff=c.flags & flag ? 0 : flag;
-	for(x1=xLow;x1<=xHigh;x1++)
-	  for(y1=yLow;y1<=yHigh;y1++) {
-		Cell& c2=map->cell(x1,y1);
-		c2.flags = (c2.flags & ~flag) | onoff;
-	  }
-	}
-	break;
+    int flag=0;
+    if(code == CODE_CELL_N) flag=CELL_NOLINENORTH;
+    if(code == CODE_CELL_S) flag=CELL_NOLINESOUTH;
+    if(code == CODE_CELL_E) flag=CELL_NOLINEEAST;
+    if(code == CODE_CELL_W) flag=CELL_NOLINEWEST;
+    int onoff=c.flags & flag ? 0 : flag;
+    for(x1=xLow;x1<=xHigh;x1++)
+      for(y1=yLow;y1<=yHigh;y1++) {
+	Cell& c2=map->cell(x1,y1);
+	c2.flags = (c2.flags & ~flag) | onoff;
+      }
+  }
+    break;
+
+  case editModeFeatures: {
+    switch(currentFeature) {
+    case FEATURE_SPIKE:
+      map->cell(x,y).heights[Cell::SOUTH+Cell::WEST] += shift?-raise:raise;
+      map->cell(x-1,y).heights[Cell::SOUTH+Cell::EAST] += shift?-raise:raise;
+      map->cell(x,y-1).heights[Cell::NORTH+Cell::WEST] += shift?-raise:raise;
+      map->cell(x-1,y-1).heights[Cell::NORTH+Cell::EAST] += shift?-raise:raise;
+      break;     
+    case FEATURE_SMALL_HILL:
+      map->cell(x,y).heights[Cell::CENTER] += (shift?-raise:raise) * 1.2;
+      for(i=0;i<4;i++) map->cell(x,y).heights[i] += (shift?-raise:raise) * 1.0;
+      map->cell(x,y+1).heights[Cell::SOUTH+Cell::EAST] += (shift?-raise:raise) * 1.0;
+      map->cell(x,y+1).heights[Cell::SOUTH+Cell::WEST] += (shift?-raise:raise) * 1.0;
+      map->cell(x,y-1).heights[Cell::NORTH+Cell::EAST] += (shift?-raise:raise) * 1.0;
+      map->cell(x,y-1).heights[Cell::NORTH+Cell::WEST] += (shift?-raise:raise) * 1.0;
+      map->cell(x+1,y).heights[Cell::SOUTH+Cell::WEST] += (shift?-raise:raise) * 1.0;
+      map->cell(x+1,y).heights[Cell::NORTH+Cell::WEST] += (shift?-raise:raise) * 1.0;
+      map->cell(x-1,y).heights[Cell::SOUTH+Cell::EAST] += (shift?-raise:raise) * 1.0;
+      map->cell(x-1,y).heights[Cell::NORTH+Cell::EAST] += (shift?-raise:raise) * 1.0;
+      map->cell(x+1,y+1).heights[Cell::SOUTH+Cell::WEST] += (shift?-raise:raise) * 1.0;
+      map->cell(x-1,y+1).heights[Cell::SOUTH+Cell::EAST] += (shift?-raise:raise) * 1.0;
+      map->cell(x+1,y-1).heights[Cell::NORTH+Cell::WEST] += (shift?-raise:raise) * 1.0;
+      map->cell(x-1,y-1).heights[Cell::NORTH+Cell::EAST] += (shift?-raise:raise) * 1.0;
+      map->cell(x+1,y+1).heights[Cell::CENTER] += (shift?-raise:raise) * 0.25;
+      map->cell(x-1,y+1).heights[Cell::CENTER] += (shift?-raise:raise) * 0.25;
+      map->cell(x+1,y-1).heights[Cell::CENTER] += (shift?-raise:raise) * 0.25;
+      map->cell(x-1,y-1).heights[Cell::CENTER] += (shift?-raise:raise) * 0.25;
+      map->cell(x+1,y).heights[Cell::CENTER] += (shift?-raise:raise) * 0.50;
+      map->cell(x-1,y).heights[Cell::CENTER] += (shift?-raise:raise) * 0.50;
+      map->cell(x,y+1).heights[Cell::CENTER] += (shift?-raise:raise) * 0.50;
+      map->cell(x,y-1).heights[Cell::CENTER] += (shift?-raise:raise) * 0.50;
+      break;
+    case FEATURE_MEDIUM_HILL: makeHill(2); break;
+    case FEATURE_LARGE_HILL: makeHill(3); break;
+    case FEATURE_HUGE_HILL: makeHill(5); break;
+    case FEATURE_SMALL_SMOOTH: doSmooth(2); break;
+    case FEATURE_LARGE_SMOOTH: doSmooth(5); break;
+    }
+  }
+    break;
   }
 }
 
