@@ -77,8 +77,8 @@ class EditMode : public GameMode {
   int menuChoise;
   int doSave;
   int hill;
-  int currentEditMode;
-
+  int currentEditMode, currentFeature;
+  
   class EMenuWindow *menuWindow;
   class EStatusWindow *statusWindow;
   class EQuitWindow *quitWindow;
