@@ -44,7 +44,7 @@ void EnterHighScoreMode::init() {
   else {
 	snprintf(str,sizeof(str),"%s/images/enterHighscoreBackground.jpg",SHARE_DIR);
 	background = IMG_Load(str);
-	if(!background) { printf("Error: Failed to load %s\n",str); exit(0); }  
+	if(!background) { printf("Error: failed to load %s\n",str); exit(0); }  
   }
 }
 EnterHighScoreMode::EnterHighScoreMode() {
@@ -109,7 +109,7 @@ void EnterHighScoreMode::activated() {
   if(!background) {
 	snprintf(str,sizeof(str),"%s/images/enterHighscoreBackground.jpg",SHARE_DIR);
 	background = IMG_Load(str);
-	if(!background) { printf("Error: Failed to load %s\n",str); exit(0); }  
+	if(!background) { printf("Error: failed to load %s\n",str); exit(0); }  
   }
 
   snprintf(name,sizeof(str),"%s",Game::current->gamer->name);
