@@ -32,7 +32,7 @@ public:
   virtual void onGet();
 
  protected:
-  int visible,x,y,points;
+  int visible,x,y;
   Real radius;
 };
 
