@@ -56,18 +56,19 @@ int char_corresp[256]=
  'o','p','q','r','s','t','u','v','w','x','y','z','0','1','2','3',
  '8','9',',',';',':','.','!','?','*','$','=','(',')','/','\\','',
  '%','&','"','{','}','[',']','|','`','\'','_','^','@','','','',
- '\0','\0',256+'"',256+'C',256+'R','\0','\0',256+'<',256+'>','\0',256+'+',256+'2',256+'3','','\0',256+'.',
+ '\0','\0',256+'"',256+'C',256+'R','\0','\0',256+'<',256+'>','','','','','','',' ',
  '\0',256+'?',256+'*',256+'O',256+'/',256+'o','P','R','S','T','k','l','m','n',256+'f',' ',
  '\0','4','5','6','7','-','+','<','>','#','~',256+'!','\0',256+'X',256+'V',256+'l',
 };
 
+
 /* access table */
+/* Index by ascii value + 128 (so we can handle 8 bit ascii (negative values!) correctly. */
 int char_access[2048]={0};
 
 /* the theoretical ratio screen_x/screen_y */
 #define SCREEN_RATIO (640./480.)
 
-
 Font *current_fonts[8] = {NULL};
 int nb_fonts = 0;
 
@@ -84,9 +85,9 @@ void Font::init() {
   int i;
   
   nb_fonts = 1;
-  current_fonts[0] = new Font("font.rgb");
-  //  current_fonts[1] = new Font("font2.rgb");
-  //current_fonts[2] = new Font("font3.rgb");
+  current_fonts[0] = new Font("font.png");
+  //current_fonts[1] = new Font("font2.png");
+  //current_fonts[2] = new Font("font3.png");
 
   // initialize texts
   for(i=0; i<MAX_TEXT_LINE; i++) {
@@ -94,34 +95,49 @@ void Font::init() {
   	textlines[i].font = NULL;
   }
   max_line_used = 0;
+
 }
 
 // load the font texture and initialize all access data
-Font::Font(char *fname) {
-  int i, j, tx, ty, k, x, y, xs, jj;
-  char _fname[1024];
+Font::Font(const char *fname) {
 
-  this->fontTex = 0;
   this->fontName = strdup(fname);
   this->color[0] = 1.;
   this->color[1] = 1.;
   this->color[2] = 1.;
   this->color[3] = 1.;
+  this->fontTex = loadTexture(this->fontName, this);
+  
+}
 
-  /* prepare font data */
-  sprintf(_fname, "%s/images/%s", SHARE_DIR, fname);
-  read_2d_image_rgb((char *)_fname, &font_data, &tx, &ty);
+
+Font::~Font() {
+}
+
+int Font::figureFontInfo(void *pixels, int tx, int ty)
+{
+  int i, j, jj, x, xs, k, y;
   if((tx != CHARS_W)||(ty != CHARS_H))
   {
     fprintf(stderr, "Font image is not %dx%d. Aborted.\n", CHARS_W, CHARS_H);
-    return;
+    return 0;
   }
-  if(font_data == NULL)
+  if(pixels == NULL)
     {
     fprintf(stderr, "Font image not loaded.\n");
-    return;
+    return 0;
     }
+
   /* create access table for chars */
+  /* Changed to handle 8bit ascii */
+  memset(char_access,0,2048);
+  for(i=0;i<256;i++) {
+	j=char_corresp[i]+128;
+	if(j >= 0 && j < 2048)
+	  char_access[j]=i;
+  }
+
+  /*
   for(i=0; i<2048; i++)
     {
     for(j=0; j<512; j++)
@@ -132,7 +148,7 @@ Font::Font(char *fname) {
         break;
         }
       }
-    }
+	  }*/
 
   /* Compute the X extention for each letter (the last non-transparent
      pixel for each letter area (32x32) */
@@ -149,7 +165,10 @@ Font::Font(char *fname) {
         {
 	for(y=0; y<CHAR_H; y++)
 	  {
-	  if (font_data[(i*CHAR_W+x+(j*CHAR_WNB*CHAR_W*CHAR_H+y*CHAR_WNB*CHAR_W))*4+3] != 0)
+	    if ((((char *)pixels)[(i*CHAR_W
+			       +x
+			       +(j*CHAR_WNB*CHAR_W*CHAR_H+y*CHAR_WNB*CHAR_W))
+			      *4+3]) != 0)
 	    {/* Not transparent. It is the letter */
 	    xs = x;
 	    x = -1;  /* hard exit for loop 1 /o) */
@@ -183,43 +202,14 @@ Font::Font(char *fname) {
       }
     }
 
-  /* Create the font textures */
-  glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
-  glGenTextures(1, &fontTex);
-  if (fontTex == 0) {
-  	fprintf(stderr, "WARNING: no font loaded.\n");
-	free(font_data);
-	return;
-  }
-  glBindTexture(GL_TEXTURE_2D, fontTex);
-  glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_REPEAT);
-  glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_REPEAT);
-  // here, texture magnifier may depend on the gfx details level
-  glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
-  glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
-  glTexImage2D(GL_TEXTURE_2D,
-	       0,
-	       4,
-	       CHARS_W,
-	       CHARS_H,
-	       0,
-	       GL_RGBA,
-	       GL_UNSIGNED_BYTE,
-	       (const GLvoid*)font_data);
-  // cleanup
-  free(font_data);
-  font_data = NULL;
+  /* Treat special '"' and '' to not move cursor forward */
+  /*
+  this->char_sizes[5*CHAR_WNB+2]=0;
+  this->char_sizes[4*CHAR_WNB+14]=0;
+  */
 }
 
-
-Font::~Font() {
-  // just delete the texture
-  if (fontTex != 0)
-    glDeleteTextures(1, &fontTex);
-  fontTex = 0;
-}
-
-int Font::addText(int font, char *text, int x, int y, float sx, float sy, double delay,
+int Font::addText(int font, const char *text, int x, int y, float sx, float sy, double delay,
                   double offset, double stab, double ampl, int fix) {
 
 	if ((font < 0)||(font >= nb_fonts))
@@ -230,7 +220,7 @@ int Font::addText(int font, char *text, int x, int y, float sx, float sy, double
 
 
 // add a text to be drawn (returns the ID of the text)
-int Font::l_addText(char *text, int x, int y, float sx, float sy, double delay,
+int Font::l_addText(const char *text, int x, int y, float sx, float sy, double delay,
                     double offset, double stab, double ampl, int fix) {
   int i, j;
   double cur;
@@ -303,7 +293,6 @@ int Font::l_addText(char *text, int x, int y, float sx, float sy, double delay,
   // update max_line
   if (i >= max_line_used)
     max_line_used = i+1;
-
   return(1);
 }
 
@@ -378,7 +367,7 @@ void Font::l_destroyAllText() {
 /* find letter index */
 static int get_letter_index_simple(int txt)
 {
-  return(char_access[txt]);
+  return(char_access[txt+128]);
 }
 
 
@@ -386,7 +375,7 @@ static int get_letter_index_simple(int txt)
    to extend the text with control sequences, in order to
    access to additionnal characters or functions */
 /* shift is the number of control characters read */
-static int get_letter_index(char *txt, int *shift)
+static int get_letter_index(const char *txt, int *shift)
 {
   *shift = 0;
 
@@ -403,14 +392,12 @@ static int get_letter_index(char *txt, int *shift)
       *shift = 1;
       return(get_letter_index_simple('#'));
       }
-    else
-    if ((txt[1] == '\'')||(txt[1] == '`')||(txt[1] == '~')||(txt[1] == '^'))
+    else if ((txt[1] == '\'')||(txt[1] == '`')||(txt[1] == '~')||(txt[1] == '^'))
       {
       *shift = -1;
       return(get_letter_index_simple(txt[1]));
       }
-    else
-    if (txt[1] == '%')
+    else if (txt[1] == '%')
       {
       *shift = -1;
       return(get_letter_index_simple('"'));
@@ -419,7 +406,7 @@ static int get_letter_index(char *txt, int *shift)
     return(get_letter_index_simple(256+txt[1]));
     }
   else  {/* standard char */
-  return(get_letter_index_simple((int)txt[0]));
+	return(get_letter_index_simple((int)txt[0]));
   }
 }
 
@@ -527,14 +514,14 @@ void Font::draw_highlight(int tl) {
 }
 
 // returns the effective width of the text
-int Font::getTextWidth(int font, char *text, float sx) {
+int Font::getTextWidth(int font, const char *text, float sx) {
   	if ((font < 0)||(font >= nb_fonts))
 	  font = 0;
 	return(current_fonts[font]->l_getTextWidth(text, sx));
 }
 
 // returns the effective width of the text
-int Font::l_getTextWidth(char *text, float sx) {
+int Font::l_getTextWidth(const char *text, float sx) {
   int i, l = 0, index, offset;
 
   if ((text == NULL)||(strlen(text) == 0))
@@ -547,9 +534,9 @@ int Font::l_getTextWidth(char *text, float sx) {
   return(l);
 }
 
-int Font::addCenterText(int font, char *text, int x, int y, float sx, float sy,
-                        double delay, double offset, double stab,
-	                double ampl, int fix) {
+int Font::addCenterText(int font, const char *text, int x, int y,
+                        float sx, float sy, double delay, double offset,
+						double stab, double ampl, int fix) {
 
 	if ((font < 0)||(font >= nb_fonts))
 	  font = 0;
@@ -558,7 +545,7 @@ int Font::addCenterText(int font, char *text, int x, int y, float sx, float sy,
 }
 
 // same than 'add_text' but 'x' is the X-center of the text to draw
-int Font::l_addCenterText(char *text, int x, int y, float sx, float sy,
+int Font::l_addCenterText(const char *text, int x, int y, float sx, float sy,
                           double delay, double offset, double stab,
 	                  double ampl, int fix) {
   int width;
@@ -567,9 +554,10 @@ int Font::l_addCenterText(char *text, int x, int y, float sx, float sy,
   return(l_addText(text, x-width/2, y, sx, sy, delay, offset, stab, ampl, fix));
 }
 
-int Font::addRightText(int font, char *text, int x, int y, float sx, float sy,
+int Font::addRightText(int font, const char *text, int x, int y,
+                       float sx, float sy,
                        double delay, double offset, double stab,
-	               double ampl, int fix) {
+                       double ampl, int fix) {
 
 	if ((font < 0)||(font >= nb_fonts))
 	  font = 0;
@@ -578,7 +566,7 @@ int Font::addRightText(int font, char *text, int x, int y, float sx, float sy,
 }
 
 // same than 'add_text' but 'x' is the right-cborder of the text to draw
-int Font::l_addRightText(char *text, int x, int y, float sx, float sy,
+int Font::l_addRightText(const char *text, int x, int y, float sx, float sy,
                          double delay, double offset, double stab,
 	                 double ampl, int fix) {
   int width;
@@ -624,7 +612,7 @@ void Font::draw() {
   glEnable(GL_TEXTURE_2D);
   for(i=0; i<=max_line_used; i++) {
   	if (textlines[i].text != NULL) {
-		glBindTexture(GL_TEXTURE_2D, textlines[i].font->fontTex);
+		bindTexture(textlines[i].font->fontName);
 		glBegin(GL_QUADS);
 		if (textlines[i].pulse) {
 		  textlines[i].font->draw_highlight(i);
@@ -722,7 +710,7 @@ void Font::l_setTransp(float a) {
   color[3] = a;
 }
 
-void Font::changeText(int tl, char *text) {
+void Font::changeText(int tl, const char *text) {
   int i;
 
   if (tl < 0)
@@ -766,7 +754,7 @@ void Font::setPulseText(int tl, int pulse) {
   }
 }
 
-int Font::drawSimpleText(int font, char *text, int x, int y, float sx, float sy, float r, float g, float b, float a) {
+int Font::drawSimpleText(int font, const char *text, int x, int y, float sx, float sy, float r, float g, float b, float a) {
 
 	if ((font < 0)||(font >= nb_fonts))
 	  font = 0;
@@ -774,7 +762,7 @@ int Font::drawSimpleText(int font, char *text, int x, int y, float sx, float sy,
 }
 
 
-int Font::drawRightSimpleText(int font, char *text, int x, int y, float sx, float sy, float r, float g, float b, float a) {
+int Font::drawRightSimpleText(int font, const char *text, int x, int y, float sx, float sy, float r, float g, float b, float a) {
 
 	if ((font < 0)||(font >= nb_fonts))
 	  font = 0;
@@ -782,14 +770,14 @@ int Font::drawRightSimpleText(int font, char *text, int x, int y, float sx, floa
 }
 
 
-int Font::drawCenterSimpleText(int font, char *text, int x, int y, float sx, float sy, float r, float g, float b, float a) {
+int Font::drawCenterSimpleText(int font, const char *text, int x, int y, float sx, float sy, float r, float g, float b, float a) {
 
 	if ((font < 0)||(font >= nb_fonts))
 	  font = 0;
 	return(current_fonts[font]->l_drawCenterSimpleText(text, x, y, sx, sy, r, g, b, a));
 }
 
-int Font::l_drawSimpleText(char *text, int x, int y, float sx, float sy, float r, float g, float b, float a) {
+int Font::l_drawSimpleText(const char *text, int x, int y, float sx, float sy, float r, float g, float b, float a) {
   int i, offset, index;
   double tm, tr, tim;
   float cx;
@@ -801,7 +789,7 @@ int Font::l_drawSimpleText(char *text, int x, int y, float sx, float sy, float r
   
   glEnable(GL_BLEND);
   glEnable(GL_TEXTURE_2D);
-  glBindTexture(GL_TEXTURE_2D, fontTex);
+  bindTexture(fontName);
   glColor4f(r, g, b, a);
 
   glBegin(GL_QUADS);
@@ -820,23 +808,23 @@ int Font::l_drawSimpleText(char *text, int x, int y, float sx, float sy, float r
   Leave2DMode();
 }
 
-int Font::l_drawRightSimpleText(char *text, int x, int y, float sx, float sy, float r, float g, float b, float a) {
+int Font::l_drawRightSimpleText(const char *text, int x, int y, float sx, float sy, float r, float g, float b, float a) {
   return(l_drawSimpleText(text, x-l_getTextWidth(text, sx), y, sx, sy, r, g, b, a));
   
 }
 
-int Font::l_drawCenterSimpleText(char *text, int x, int y, float sx, float sy, float r, float g, float b, float a) {
+int Font::l_drawCenterSimpleText(const char *text, int x, int y, float sx, float sy, float r, float g, float b, float a) {
   return(l_drawSimpleText(text, x-l_getTextWidth(text, sx)/2, y, sx, sy, r, g, b, a));
 }
 
-int Font::drawSimpleText3D(int font, char *text, float sx, float sy) {
+int Font::drawSimpleText3D(int font, const char *text, float sx, float sy) {
 
 	if ((font < 0)||(font >= nb_fonts))
 	  font = 0;
 	return(current_fonts[font]->l_drawSimpleText3D(text, sx, sy));
 }
 
-int Font::l_drawSimpleText3D(char *text, float sx, float sy) {
+int Font::l_drawSimpleText3D(const char *text, float sx, float sy) {
   int i, offset, index;
   double tm, tr, tim;
   float cx, y;
@@ -846,18 +834,19 @@ int Font::l_drawSimpleText3D(char *text, float sx, float sy) {
   
   glEnable(GL_BLEND);
   glEnable(GL_TEXTURE_2D);
-  glBindTexture(GL_TEXTURE_2D, fontTex);
+  bindTexture(fontName);
   glBegin(GL_QUADS);
 
   cx = 0.;
   y = 0.;
   for(i=0; i<strlen(text); i++) {
+
   	index = get_letter_index(text + i, &offset);
 
 	draw_a_char3D(index, cx, y, sx, sy);
-        i += offset;
-        cx += (float)(2.*sx*char_sizes[index]);
-	}
+	i += offset;
+	cx += (float)(2.*sx*char_sizes[index]);
+  }
 
   glEnd();
 }
