@@ -24,6 +24,7 @@
 #include "player.h"
 #include "map.h"
 #include "game.h"
+#include "settings.h"
 
 using namespace std;
 
@@ -44,6 +45,8 @@ Fountain::Fountain(double randomSpeed,double radius,double strength)
 void Fountain::draw2() {
   int i;
 
+  if(Settings::settings->gfx_details <= GFX_DETAILS_MINIMALISTIC) return;
+
   glPushAttrib(GL_ENABLE_BIT);
   glEnable(GL_BLEND);
   glDisable(GL_LIGHTING);
@@ -57,23 +60,27 @@ void Fountain::draw2() {
 	if(drawFrom == nextPoint) break;
 	drawFrom=(drawFrom+1)%800;
   }	
+  int skip=Settings::settings->gfx_details <= GFX_DETAILS_SIMPLE ? 2 : 1;
+  if(fps < 5) skip *= 2;
+
   if(nextPoint<drawFrom) {   
-	for(i=drawFrom;i<800;i++) glVertex3f(positions[i][0],positions[i][1],positions[i][2]);
-	for(i=0;i<nextPoint;i++) glVertex3f(positions[i][0],positions[i][1],positions[i][2]);
+	for(i=drawFrom;i<800;i+=skip) glVertex3f(positions[i][0],positions[i][1],positions[i][2]);
+	for(i=0;i<nextPoint;i+=skip) glVertex3f(positions[i][0],positions[i][1],positions[i][2]);
   } else
-	for(i=drawFrom;i<nextPoint;i++) glVertex3f(positions[i][0],positions[i][1],positions[i][2]);
+	for(i=drawFrom;i<nextPoint;i+=skip) glVertex3f(positions[i][0],positions[i][1],positions[i][2]);
   glEnd();
   glPopAttrib();
 }
 
 void Fountain::tick(Real t) {
   int i,j;
+  int skip=Settings::settings->gfx_details <= GFX_DETAILS_SIMPLE ? 2 : 1;
 
   if(nextPoint<drawFrom) {   
-	for(i=drawFrom;i<800;i++) { for(j=0;j<3;j++) positions[i][j] += velocities[i][j]; velocities[i][2] -= t * 1.0; }
-	for(i=0;i<nextPoint;i++) { for(j=0;j<3;j++) positions[i][j] += velocities[i][j]; velocities[i][2] -= t * 1.0; }
+	for(i=drawFrom;i<800;i+=skip) { for(j=0;j<3;j++) positions[i][j] += velocities[i][j]; velocities[i][2] -= t * 1.0; }
+	for(i=0;i<nextPoint;i+=skip) { for(j=0;j<3;j++) positions[i][j] += velocities[i][j]; velocities[i][2] -= t * 1.0; }
   } else
-	for(i=drawFrom;i<nextPoint;i++) { for(j=0;j<3;j++) positions[i][j] += velocities[i][j]; velocities[i][2] -= t * 1.0; }
+	for(i=drawFrom;i<nextPoint;i+=skip) { for(j=0;j<3;j++) positions[i][j] += velocities[i][j]; velocities[i][2] -= t * 1.0; }
 
   Real timeNow=Game::current->gameTime;
   createPoint+=t*strength;
@@ -92,7 +99,7 @@ void Fountain::tick(Real t) {
   
   // YP: 'push' player if above
   if (strength > 0.) {
-  	//position[2] = Game::current->map->getHeight(position[0],position[1]);   //MB. No thanks, let's keep the old position
+  	//position[2] = Game::current->map->getHeight(position[0],position[1]);   //MB. No thanks, let's keep the old position it messes with some maps otherwise
   	Player *p = Game::current->player1;
   	Coord3d diff;
 
