@@ -31,6 +31,7 @@
 #include "settings.h"
 #include "pipe.h"
 #include "weather.h"
+#include "sound.h"
 
 #define MARGIN 10
 
@@ -40,6 +41,8 @@ Game *Game::current=NULL;
 
 extern GLfloat colors[5][3];
 
+double Game::defaultScores[SCORE_MAX][2];
+
 Game::Game(char *name,Gamer *g) {
   Ball::reset();
   ForceField::reset();
@@ -87,10 +90,10 @@ void Game::loadLevel(char *name) {
   char scmname[256];
 
   if(player1) {
-	// level scripts might have modified our appearance. Reset them
-	for(int i=0;i<3;i++) 
-	  player1->primaryColor[i] = colors[gamer->color][i];
-	player1->texture = textures[gamer->textureNum];
+    // level scripts might have modified our appearance. Reset them
+    for(int i=0;i<3;i++) 
+      player1->primaryColor[i] = colors[gamer->color][i];
+    player1->texture = textures[gamer->textureNum];
   }
   
   setDefaults();  
@@ -114,7 +117,10 @@ void Game::loadLevel(char *name) {
 
   fogThickness=wantedFogThickness;
 }
+
 void Game::setDefaults() {
+  int i;
+
   isNight = 0;
   fogThickness=0.0; wantedFogThickness=0.0;
   startTime = 0;
@@ -122,7 +128,31 @@ void Game::setDefaults() {
   useGrid=1;
   jumpFactor=1.0;
   oxygenFactor=1.0;
-  restartBonusTime = 45.0;
+
+  for(i=0;i<SCORE_MAX;i++) {
+    defaultScores[i][0] = 0.0;
+    defaultScores[i][1] = 0.0;
+  }
+  defaultScores[SCORE_PLAYER][0]=-100;
+  defaultScores[SCORE_PLAYER][1]=60 - 5*Settings::settings->difficulty;
+  defaultScores[SCORE_BLACK][0]=100;
+  defaultScores[SCORE_BLACK][1]=0;
+  defaultScores[SCORE_BABY][0]=50;
+  defaultScores[SCORE_BABY][1]=5-2*Settings::settings->difficulty;
+  defaultScores[SCORE_BIRD][0]=100;
+  defaultScores[SCORE_BIRD][1]=0;
+  defaultScores[SCORE_CACTUS][0]=100;
+  defaultScores[SCORE_CACTUS][1]=0;
+  defaultScores[SCORE_FLAG][0]=100;
+  defaultScores[SCORE_FLAG][1]=0;
+
+  /* Since the player object lives on from level to level we need to
+     reset it's default values here too */
+  if(player1) {
+    player1->scoreOnDeath = defaultScores[SCORE_PLAYER][0];
+    player1->timeOnDeath = defaultScores[SCORE_PLAYER][1];
+  }
+
 }
 
 void Game::clearLevel() {
@@ -130,6 +160,7 @@ void Game::clearLevel() {
   ForceField::reset();
 
   weather->clear();
+  clearMusicPreferences();
   if(hooks) {
     set<GameHook*> *old_hooks = new set<GameHook*>(*hooks);
     set<GameHook*>::iterator ih = old_hooks->begin();
@@ -167,7 +198,8 @@ void Game::doExpensiveComputations() {
   set<GameHook*>::iterator ih = old_hooks->begin();
   set<GameHook*>::iterator endh = old_hooks->end();
 
-  for(;ih!=endh;ih++) (*ih)->doExpensiveComputations();
+  for(;ih!=endh;ih++)
+    (*ih)->doExpensiveComputations();
   delete old_hooks;  
 }
 
@@ -302,7 +334,6 @@ void Game::add(GameHook *a) {
 }
 void Game::remove(Animated *a) {
   objects->erase(a);
-  //  printf("game::remove after - num objects is %d\n",objects->size());
 }
 void Game::remove(GameHook *a) {
   hooks->erase(a);
