@@ -28,10 +28,12 @@
 
 class GameMode {
  public:
+  GameMode();
   virtual ~GameMode();
 
   virtual void display();
   virtual void key(int);
+  virtual void keyUp(int);
   virtual void special(int,int,int);
   virtual void idle(Real dt);
   virtual void doExpensiveComputations();
@@ -43,6 +45,7 @@ class GameMode {
   static void activate(GameMode*);
   static GameMode *current;
  protected:
+  int keyUpReceived;
  private:
 };
 
