@@ -84,7 +84,7 @@ void Gamer::levelStarted() {
    files are meant to be local. */
 void Gamer::save() {
   char str[256];
-  int version=2;
+  int version=3;
   int levelSet;
 
   Settings *settings=Settings::settings;
@@ -117,6 +117,7 @@ void Gamer::save() {
 	  gzwrite(gp,&nKnownLevels[levelSet],sizeof(int));
 	  gzwrite(gp,levels[levelSet],sizeof(KnownLevel)*nKnownLevels[levelSet]);
 	}
+	gzwrite(gp,&(Settings::settings->sandbox),sizeof(int));
 	gzclose(gp);
   }
 }
@@ -129,7 +130,7 @@ void Gamer::update() {
   gzFile gp = gzopen(str,"rb");
   if(!gp) { setDefaults(); return; }
   gzread(gp,&version,sizeof(int));
-  if(version != 2) {printf("Warning. Ignoring outdated player profile for player %s\n",name); return;}
+  if(version < 2) {printf("Warning. Ignoring outdated player profile for player %s\n",name); return;}
   gzread(gp,&color,sizeof(int));
   gzread(gp,&totalScore,sizeof(int));
   gzread(gp,&nLevelsCompleted,sizeof(int));
@@ -151,7 +152,9 @@ void Gamer::update() {
 	gzread(gp,&nKnownLevels[levelSet],sizeof(int));
 	gzread(gp,levels[levelSet],sizeof(KnownLevel)*nKnownLevels[levelSet]);   
   }
-
+  if(version >= 3) {
+    gzread(gp,&(Settings::settings->sandbox),sizeof(int));
+  }
   gzclose(gp);
 }
 void Gamer::playerLoose() {
