@@ -36,9 +36,9 @@ class HelpMode : public GameMode {
   static HelpMode *helpMode;
  private:
   double timeLeft;
-  int isExiting,selected,page;
-  static SDL_Surface *background,*moreHelp,*moreHelpHigh;
-  static SDL_Surface *back,*backHigh,*page0,*page1;
+  int isExiting,page;
+  static SDL_Surface *background;
+  static SDL_Surface *page0,*page1;
 
   GLuint bgTexture,p0Texture,p1Texture;
   GLfloat texMinX, texMinY, texMaxX, texMaxY;
