@@ -1,6 +1,7 @@
-/* highScore.cc
+/** \file highScore.cc
    Saves and loads the highscore lists
-
+*/
+/*
    Copyright (C) 2000  Mathias Broxvall
 
    This program is free software; you can redistribute it and/or modify
@@ -29,19 +30,34 @@ char highScorePath[256];
 
 HighScore *HighScore::highScore;
 HighScore::HighScore() {
-  int i;
+  int i,j;
 
   for(int levelSet=0;levelSet<Settings::settings->nLevelSets;levelSet++)
 	for(i=0;i<10;i++) {
 	  points[levelSet][i] = 1000 - i * 100;
-	  sprintf(names[levelSet][i],"Anonymous Coward");
+	  snprintf(names[levelSet][i],sizeof(names[levelSet][i]),"Anonymous Coward");
 	}
 
 #ifdef ALT_HIGHSCORES
-  sprintf(highScorePath,"%s",ALT_HIGHSCORES);
+
+  /* Copy ALT_HIGHSCORES into highScorePath, substituting the '~' character for the HOME directory */
+  if(ALT_HIGHSCORES[0] == '~') {
+    if(ALT_HIGHSCORES[1] == 0) 
+      snprintf(highScorePath,sizeof(highScorePath),"%s/.trackballs/highscores",getenv("HOME"));
+    else if(ALT_HIGHSCORES[1] == '/')
+      snprintf(highScorePath,sizeof(highScorePath),"%s%s",getenv("HOME"),&ALT_HIGHSCORES[1]);
+    else { printf("Error, bad ALT_HIGHSCORES compiled into game '%s'\n",ALT_HIGHSCORES); exit(0); }
+  } else {
+    snprintf(highScorePath,sizeof(highScorePath),"%s",ALT_HIGHSCORES);
+  }
+
 #else
-  sprintf(highScorePath,"%s/highScores",SHARE_DIR);
+  snprintf(highScorePath,sizeof(highScorePath),"%s/highScores",SHARE_DIR);
 #endif
+  if(pathIsLink(highScorePath)) {
+	fprintf(stderr,_("Error, %s is a symbolic link. Cannot save highscores\n"),highScorePath);
+	return;
+  }
   gzFile gp = gzopen(highScorePath,"rb");
   if(!gp) { printf("Warning. Could not find highscore file %s\n",highScorePath); return; }
   int nLevelSets,levelSet;
@@ -81,6 +97,11 @@ void HighScore::addHighScore(int score,char *name) {
 	points[levelSet][i] = score;
   }
 
+  if(pathIsLink(highScorePath)) {
+	fprintf(stderr,_("Error, %s is a symbolic link. Cannot save highscores\n"),highScorePath);
+	return;
+  }
+
   Settings *settings=Settings::settings;
   gzFile gp = gzopen(highScorePath,"wb9");
   if(!gp) { printf("Warning. Cannot save highscores at %s, check file permissions\n",highScorePath); return; }
