@@ -43,7 +43,7 @@ void HallOfFameMode::init() {
   else {
 	snprintf(str,sizeof(str),"%s/images/displayHighscoreBackground.jpg",SHARE_DIR);
 	background=IMG_Load(str);
-	if(!background) { printf(_("Error: Failed to load %s\n"),str); exit(0); } 
+	if(!background) { printf("Error: failed to load %s\n",str); exit(0); } 
   }
   hallOfFameMode = new HallOfFameMode();
 }
@@ -54,7 +54,7 @@ void HallOfFameMode::activated() {
   if(!background) {
 	snprintf(str,sizeof(str),"%s/images/displayHighscoreBackground.jpg",SHARE_DIR);
 	background=IMG_Load(str);
-	if(!background) { printf(_("Error: Failed to load %s\n"),str); exit(0); } 
+	if(!background) { printf("Error: failed to load %s\n",str); exit(0); } 
   }
 
   /* Loads the background images. */
