@@ -314,10 +314,9 @@ void MainMode::key(int key) {
     break;
   case statusRestartPlayer:
     if(key == ' ') {
-	  restartPlayer();
-	  player1->timeLeft += (int) Game::current->restartBonusTime;
-	  gameStatus=statusInGame;
-	}
+      restartPlayer();
+      gameStatus=statusInGame;
+    }
     break;
   case statusPaused:
     if(key != 'p' && key != 'P')
