@@ -1,6 +1,7 @@
-/* map.cc
+/** \file map.cc
    Handles all information about the current map, including the individual cells.
-
+*/
+/*
    Copyright (C) 2000  Mathias Broxvall
    		       Yannick Perret
 
@@ -38,8 +39,8 @@ using namespace std;
 const int Map::flagNone=0,Map::flagFlashCenter=1,Map::flagTranslucent=2,Map::flagShowCross=4;
 const int Map::mapFormatVersion=7;
 
-int32_t saveInt(int32_t v) { return (int32_t) SDL_SwapBE32((uint32_t)v); }
-int32_t loadInt(int32_t v) { return (int32_t) SDL_SwapBE32((uint32_t)v); }
+inline int32_t saveInt(int32_t v) { return (int32_t) SDL_SwapBE32((uint32_t)v); }
+inline int32_t loadInt(int32_t v) { return (int32_t) SDL_SwapBE32((uint32_t)v); }
 
 /* initialization of some fields to be sure... */
 Cell::Cell()  {
@@ -198,8 +199,15 @@ Map::Map(char *filename) {
 
   cachedCX=cachedCY=-1,cacheCount=0;
 
-  sprintf(mapname,"Unknown");
-  sprintf(author,"Unknown");
+  /* Data structures for maintaining displaylists.
+	 We allocate 50 * 50 * 2 display lists for 50 x 50 x/y coordinates and 2 drawing stages 
+  */
+  nListsWide=50;
+  nLists = nListsWide*nListsWide*2;
+  displayLists = (int) glGenLists(nLists);
+
+  snprintf(mapname,sizeof(mapname),_("Unknown track"));
+  snprintf(author,sizeof(author),_("Unknown author"));
   gp=gzopen(filename,"rb");
   if(gp) {
 	int version;
@@ -215,6 +223,7 @@ Map::Map(char *filename) {
 	  printf("Warning. Map %s is of an old format (v%d, latest is v%d)\n",filename,version,mapFormatVersion);
 	else if(version > mapFormatVersion) {
 	  fprintf(stderr,"Error. Map %s is from the future (v%d, I know only format v%d)",filename,version,mapFormatVersion);
+	  fprintf(stderr,"This error usually occurs because or broken maps or big/small endian issues\n");
 	  exit(0);
 	}
 
@@ -240,6 +249,7 @@ Map::Map(char *filename) {
 			c.textureCoords[north*Cell::NORTH+east*Cell::EAST][0] = (x+east)/4.0;
 			c.textureCoords[north*Cell::NORTH+east*Cell::EAST][1] = (y+north)/4.0;
 		  }
+		
 		c.load(this,gp,version);		
 	  }
     gzclose(gp);
@@ -252,6 +262,7 @@ Map::Map(char *filename) {
     for(x=0;x<width;x++)
       for(y=0;y<height;y++) {
 		Cell& c = cells[x+y*width];
+
 		c.flags = 0;
 		for(i=0;i<5;i++) {
 		  c.heights[i] = -8.0;
@@ -273,6 +284,16 @@ Map::Map(char *filename) {
 		  }
       }
   }
+
+  /* Fix display lists used by each cell */
+  for(y=0;y<height;y++)
+	for(x=0;x<width;x++) {
+	  Cell& c = cells[x+y*width];	  
+	  c.displayList = displayLists + ((x % nListsWide) + (y % nListsWide) * nListsWide)*2;
+	  c.displayListLastCompiled=-1;
+	  c.displayListDirty=1;
+	}
+
   flags = flagNone;      
   startPosition[2]=getHeight(startPosition[0],startPosition[1]);
 
@@ -280,9 +301,11 @@ Map::Map(char *filename) {
   tx_Acid=loadTexture("acid.png");
   tx_Sand=loadTexture("sand.png");
   tx_Track=loadTexture("track.png");
+
 }
 Map::~Map() {
   //  glDeleteLists(cache[0].lists[0],(width/4)*(height/4));
+  glDeleteLists(displayLists,nLists);
   delete cells;
 }
 
@@ -293,6 +316,8 @@ void Map::draw(int birdsEye,int stage,int cx,int cy) {
   int gfx_details = Settings::settings->gfx_details;
 
   if(stage > 0 && !isTransparent) return;
+  static int frameCount=0;
+  frameCount++;
 
   glPushAttrib(GL_ENABLE_BIT);
 
@@ -320,6 +345,8 @@ void Map::draw(int birdsEye,int stage,int cx,int cy) {
 #define MARGIN 50
 
   if(cx != cachedCX || cy != cachedCY || cacheCount > 10) {
+	double t0 = getSystemTime();
+
     glGetIntegerv(GL_VIEWPORT, viewport);
     glGetDoublev(GL_MODELVIEW_MATRIX, model_matrix);
     glGetDoublev(GL_PROJECTION_MATRIX, proj_matrix);
@@ -327,6 +354,7 @@ void Map::draw(int birdsEye,int stage,int cx,int cy) {
     Coord3d worldCoord,screenCoord;
 
 	int ix,iy;
+	int visibleCnt=0;
 
 	for(ix=0;ix<41;ix++)
 	  for(iy=0;iy<41;iy++) {
@@ -338,7 +366,7 @@ void Map::draw(int birdsEye,int stage,int cx,int cy) {
 				   model_matrix,proj_matrix,viewport,
 				   &screenCoord[0], &screenCoord[1], &screenCoord[2]);
 		if(screenCoord[0] >= - MARGIN && screenCoord[0] <= screenWidth+MARGIN &&
-			 screenCoord[1] >= - MARGIN && screenCoord[1] <= screenHeight+MARGIN) { cacheVisible[ix][iy]=1; continue; }
+		   screenCoord[1] >= - MARGIN && screenCoord[1] <= screenHeight+MARGIN) { cacheVisible[ix][iy]=1; visibleCnt++; continue; }
 		for(int north=0;north<2;north++)
 		  for(int east=0;east<2;east++) {
 			worldCoord[0]=x+1.0*east; worldCoord[1]=y+1.0*north; worldCoord[2]=cell(x,y).heights[north*Cell::NORTH+east*Cell::EAST];
@@ -348,6 +376,7 @@ void Map::draw(int birdsEye,int stage,int cx,int cy) {
 			if(screenCoord[0] >= - MARGIN && screenCoord[0] <= screenWidth+MARGIN &&
 			   screenCoord[1] >= - MARGIN && screenCoord[1] <= screenHeight+MARGIN) {
 			  cacheVisible[ix][iy]=1;
+			  visibleCnt++;
 			  goto cont; // The almighty goto statment, don't do this at home kids!
 			}
 		  }			
@@ -361,133 +390,81 @@ void Map::draw(int birdsEye,int stage,int cx,int cy) {
 	cachedCX = cx;
 	cachedCY = cy;
 	cacheCount = 0;
+   
+	//printf("Time for cache check: %3.3fms\n",1000.0*(getSystemTime()-t0));
+	//printf("%d cells visible\n",visibleCnt);
   } else
 	cacheCount++;
 
-  /* First, draw the cells */
+  /* If we are doing stage 0 then recompile all display lists (both stage 0 and stage 1) 
+	 that are either too old or have been marked as dirty */
+  int redrawCnt=0;
+  if(stage == 0) 
+	for(ix=0;ix<41;ix++)
+	  for(iy=0;iy<41;iy++)
+	  if(cacheVisible[ix][iy]) {		
+		x=cx+ix-20; y=cy+iy-20;
+		if(x>=0&&x<width&&y>=0&&y<height) {
+		  Cell& c = cell(x,y);
+		  if(c.displayListLastCompiled + 10 < frameCount || c.displayListDirty || c.velocity[0] != 0.0 || c.velocity[1] != 0.0) {
+			redrawCnt++;
+			c.displayListLastCompiled = frameCount;
+			c.displayListDirty=0;
+			int thisStage=0;
+			glNewList(c.displayList+thisStage,GL_COMPILE);
+			drawCell(birdsEye,thisStage,x,y);			
+			glEndList();
+			if(isTransparent) {
+			  thisStage=1;
+			  glNewList(c.displayList+thisStage,GL_COMPILE);
+			  drawCell(birdsEye,thisStage,x,y);			
+			  glEndList();
+			}
+		  }
+		}
+	  }
+  //printf("%d cells redrawn\n",redrawCnt);
+
+  /* Call all the display lists to draw the actual ground */
   for(ix=0;ix<41;ix++)
 	for(iy=0;iy<41;iy++)
 	  if(cacheVisible[ix][iy]) {
 		x=cx+ix-20; y=cy+iy-20;
-		if(x>=0&&x<width&&y>=0&&y<height)
-		  drawCell(birdsEye,stage,x,y);
+		if(x>=0&&x<width&&y>=0&&y<height) {
+		  Cell& c = cell(x,y);		  
+		  glCallList(c.displayList+stage);
+		}
 	  }
+  glPopMatrix();
 
-  /* Now draw the lines around the cells */
-  glMatrixMode(GL_PROJECTION);
-  glPushMatrix();
-  glTranslatef(0,0,0.02);
-  GLfloat gridColor[4] = {0.0,0.0,0.0,0.8};
-  glMaterialfv(GL_FRONT,GL_AMBIENT_AND_DIFFUSE,gridColor);
-  glNormal3f(0.0,0.0,1.0);
+  glPopAttrib();
+}
+void Map::drawFootprint(int x,int y,int kind) {
+  Cell& center = cell(x,y);
+  glPushAttrib(GL_ENABLE_BIT);
+  glDisable(GL_DEPTH_TEST);
 
   if(Settings::settings->gfx_details >= 4) {
 	glEnable(GL_BLEND);
 	glEnable(GL_LINE_SMOOTH);
 	glHint(GL_LINE_SMOOTH_HINT,GL_NICEST);
-	glLineWidth(1.0);
-	if (Settings::settings->gfx_details >= 5) {
-	       glEnable(GL_POLYGON_SMOOTH);
-	}
-  } else {
-	glDisable(GL_BLEND);
-	glDisable(GL_LINE_SMOOTH);
-	glLineWidth(1.0);
   }
-
-  if((!Game::current) || Game::current->useGrid)
-	for(ix=0;ix<41;ix++)
-	  for(iy=0;iy<41;iy++)
-		if(cacheVisible[ix][iy]) {
-		  x=cx+ix-20; y=cy+iy-20;
-		  if(x>=0&&x<width&&y>=0&&y<height) {
-			Cell& c=cell(x,y);
-			if(!(c.flags & CELL_NOGRID)) {
-			  if (!(c.flags & CELL_NOLINESOUTH) ) {
-				glBegin(GL_LINES);
-				glVertex3f(x,y,c.heights[Cell::SOUTH+Cell::WEST]);
-				glVertex3f(x+1,y,c.heights[Cell::SOUTH+Cell::EAST]);
-				glEnd();  }
-			  if (! (c.flags & CELL_NOLINEEAST) ) {
-				glBegin(GL_LINES);
-				glVertex3f(x+1,y,c.heights[Cell::SOUTH+Cell::EAST]);
-				glVertex3f(x+1,y+1,c.heights[Cell::NORTH+Cell::EAST]);
-				glEnd();  }
-			  if (! (c.flags & CELL_NOLINENORTH) ) {
-				glBegin(GL_LINES);
-				glVertex3f(x+1,y+1,c.heights[Cell::NORTH+Cell::EAST]);
-				glVertex3f(x,y+1,c.heights[Cell::NORTH+Cell::WEST]);
-				glEnd();  }
-			  if (! (c.flags & CELL_NOLINEWEST) ) {
-				glBegin(GL_LINES);
-				glVertex3f(x,y+1,c.heights[Cell::NORTH+Cell::WEST]);
-				glVertex3f(x,y,c.heights[Cell::SOUTH+Cell::WEST]);
-				glEnd();    }  
-			}
-		  }
-		}
-  glPopMatrix();
-
-  /*
-  int nDrawn,onScreen,onScreens[41];
-  for(i=0;i<41;i++) onScreens[i]=0;
-
-  for(y=cy-20;y<=cy+20;y++) {
-	for(x=cx,onScreen=1;x>=cx-20;x--) {
-	  drawCell(birdsEye,stage,x,y);
-	  if(onScreen) {
-		worldCoord[0]=x+.5; worldCoord[1]=y+.5; worldCoord[2]=cell(x,y).heights[Cell::CENTER];
-		gluProject(worldCoord[0], worldCoord[1], worldCoord[2],
-				   model_matrix,proj_matrix,viewport,
-				   &screenCoord[0], &screenCoord[1], &screenCoord[2]);
-		if((screenCoord[0] >= -100 && screenCoord[0] <= screenWidth+100 &&
-			screenCoord[1] >= -100 && screenCoord[1] <= screenHeight+100))
-		  onScreen=onScreens[x-cx+20]=1;
-		else onScreen=0;
-	  } else if(onScreens[x-cx+20])
-		onScreens[x-cx+20]=0;
-	  else break;
-	}
-	for(x=cx+1,onScreen=1;x<=cx+20;x++) {
-	  drawCell(birdsEye,stage,x,y);
-	  if(onScreen) {
-		worldCoord[0]=x+.5; worldCoord[1]=y+.5; worldCoord[2]=cell(x,y).heights[Cell::CENTER];
-		gluProject(worldCoord[0], worldCoord[1], worldCoord[2],
-				   model_matrix,proj_matrix,viewport,
-				   &screenCoord[0], &screenCoord[1], &screenCoord[2]);
-		if((screenCoord[0] >= -100 && screenCoord[0] <= screenWidth+100 &&
-			screenCoord[1] >= -100 && screenCoord[1] <= screenHeight+100))
-		  onScreen=onScreens[x-cx+20]=1;
-		else onScreen=0;
-	  } else if(onScreens[x-cx+20])
-		onScreens[x-cx+20]=0;
-	  else break;
-	}
-	}*/
-
-
-
-
-  glPopAttrib();
-}
-void Map::drawFootprint(int x,int y) {
-  Cell& center = cell(x,y);
-  glPushAttrib(GL_ENABLE_BIT);
-  glDisable(GL_DEPTH_TEST);
-
-  glLineWidth(3);
+  glLineWidth(4);
   glMatrixMode(GL_PROJECTION);
   glPushMatrix();
   glTranslatef(0,0,0.02);
 
+  glDisable(GL_LIGHTING);
   glBegin(GL_LINE_LOOP); {
-	glColor4f(1.0,1.0,0.2,1.0);
+	if(kind == 0) glColor4f(0.2,0.2,0.5,1.0);
+	else if(kind == 1) glColor4f(0.5,0.2,0.2,1.0);
 	glVertex3f(x,y,center.heights[Cell::SOUTH+Cell::WEST]);
 	glVertex3f(x+1,y,center.heights[Cell::SOUTH+Cell::EAST]);
 	glVertex3f(x+1,y+1,center.heights[Cell::NORTH+Cell::EAST]);
 	glVertex3f(x,y+1,center.heights[Cell::NORTH+Cell::WEST]);
   } glEnd();
 
+  glLineWidth(1);
   glPopMatrix();
   glPopAttrib();
 }
@@ -500,7 +477,7 @@ double smoothSemiRand(int x,int y,double scale) {
 }
 
 void Map::drawCell(int birdsEye,int stage,int x,int y) {
-  Coord3d normal;
+  Coord3d normal,normal1;
   Real texScale = 0.25;
   int i,draw;
   int gfx_details = Settings::settings->gfx_details;
@@ -532,16 +509,17 @@ void Map::drawCell(int birdsEye,int stage,int x,int y) {
 	txOffset=-(Game::current?Game::current->gameTime:((EditMode*)GameMode::current)->time)*c.velocity[0]*texScale;
 	tyOffset=-(Game::current?Game::current->gameTime:((EditMode*)GameMode::current)->time)*c.velocity[1]*texScale;
   }
+  /* TODO. Do txOffset as a texture matrix transformation instead? */
 
   int topTransparent=0;
   for(i=0;i<5;i++) if(c.colors[i][3] < 0.95) topTransparent=1;
 
-  /* Draw top of this cell */
+  /*** Draw the filled content of the top of this cell ***/
   if((topTransparent && stage==1) || (!topTransparent && stage==0)  || !isTransparent) {
 	if(gfx_details >= 1) 
 	  glBegin(GL_TRIANGLE_FAN); 
 	else
-	  glBegin(GL_POLYGON); 
+	  glBegin(GL_QUADS); 
 	{	
 	  /* Specify vertices */
 	  if(gfx_details >= 1) {
@@ -550,55 +528,91 @@ void Map::drawCell(int birdsEye,int stage,int x,int y) {
 		glMaterialfv(GL_FRONT,GL_AMBIENT_AND_DIFFUSE,c.colors[Cell::CENTER]);
 		glTexCoord2f((c.textureCoords[0][0]+c.textureCoords[1][0]+c.textureCoords[2][0]+c.textureCoords[3][0])/4.0+txOffset,
 					 (c.textureCoords[0][1]+c.textureCoords[1][1]+c.textureCoords[2][1]+c.textureCoords[3][1])/4.0+tyOffset);
-		//glTexCoord2f((0.5+x)*texScale+txOffset,(0.5+y)*texScale+tyOffset);
 		glVertex3f(x+0.5,y+0.5,c.heights[Cell::CENTER]);
 	  }
 
-	  c.getNormal(normal,Cell::SOUTH+Cell::WEST);
-	  glNormal3dv(normal);
+	  /* Note the use of "normal1" here so we can reuse it for the last vertice */
+	  c.getNormal(normal1,Cell::SOUTH+Cell::WEST);
+	  glNormal3dv(normal1);
 	  glMaterialfv(GL_FRONT,GL_AMBIENT_AND_DIFFUSE,c.colors[Cell::SOUTH+Cell::WEST]);
 	  glTexCoord2f(c.textureCoords[Cell::SOUTH+Cell::WEST][0]+txOffset,c.textureCoords[Cell::SOUTH+Cell::WEST][1]+tyOffset);
-	  //glTexCoord2f((0.0+x)*texScale+txOffset,(0.0+y)*texScale+tyOffset);
 	  glVertex3f(x,y,c.heights[Cell::SOUTH+Cell::WEST]);
 	
 	  c.getNormal(normal,Cell::SOUTH+Cell::EAST);
 	  glNormal3dv(normal);
 	  glMaterialfv(GL_FRONT,GL_AMBIENT_AND_DIFFUSE,c.colors[Cell::SOUTH+Cell::EAST]);
 	  glTexCoord2f(c.textureCoords[Cell::SOUTH+Cell::EAST][0]+txOffset,c.textureCoords[Cell::SOUTH+Cell::EAST][1]+tyOffset);
-	  //glTexCoord2f((1.0+x)*texScale+txOffset,(0.0+y)*texScale+tyOffset);
 	  glVertex3f(x+1.01,y,c.heights[Cell::SOUTH+Cell::EAST]);
 	  
 	  c.getNormal(normal,Cell::NORTH+Cell::EAST);
 	  glNormal3dv(normal);
 	  glMaterialfv(GL_FRONT,GL_AMBIENT_AND_DIFFUSE,c.colors[Cell::NORTH+Cell::EAST]);
 	  glTexCoord2f(c.textureCoords[Cell::NORTH+Cell::EAST][0]+txOffset,c.textureCoords[Cell::NORTH+Cell::EAST][1]+tyOffset);
-	  //glTexCoord2f((1.0+x)*texScale+txOffset,(1.0+y)*texScale+tyOffset);
 	  glVertex3f(x+1.01,y+1.01,c.heights[Cell::NORTH+Cell::EAST]);
 	  
 	  c.getNormal(normal,Cell::NORTH+Cell::WEST);
 	  glNormal3dv(normal);
 	  glMaterialfv(GL_FRONT,GL_AMBIENT_AND_DIFFUSE,c.colors[Cell::NORTH+Cell::WEST]);
 	  glTexCoord2f(c.textureCoords[Cell::NORTH+Cell::WEST][0]+txOffset,c.textureCoords[Cell::NORTH+Cell::WEST][1]+tyOffset);
-	  //glTexCoord2f((0.0+x)*texScale+txOffset,(1.0+y)*texScale+tyOffset);
 	  glVertex3f(x,y+1.01,c.heights[Cell::NORTH+Cell::WEST]);
 		
-	  c.getNormal(normal,Cell::SOUTH+Cell::WEST);
-	  glNormal3dv(normal);
-	  glMaterialfv(GL_FRONT,GL_AMBIENT_AND_DIFFUSE,c.colors[Cell::SOUTH+Cell::WEST]);
-	  glTexCoord2f(c.textureCoords[Cell::SOUTH+Cell::WEST][0]+txOffset,c.textureCoords[Cell::SOUTH+Cell::WEST][1]+tyOffset);
-	  //glTexCoord2f((0.0+x)*texScale+txOffset,(0.0+y)*texScale+tyOffset);
-	  glVertex3f(x,y,c.heights[Cell::SOUTH+Cell::WEST]);
+	  if(gfx_details >= 1) {
+		glNormal3dv(normal1);
+		glMaterialfv(GL_FRONT,GL_AMBIENT_AND_DIFFUSE,c.colors[Cell::SOUTH+Cell::WEST]);
+		glTexCoord2f(c.textureCoords[Cell::SOUTH+Cell::WEST][0]+txOffset,c.textureCoords[Cell::SOUTH+Cell::WEST][1]+tyOffset);
+		glVertex3f(x,y,c.heights[Cell::SOUTH+Cell::WEST]);
+	  }
 	} glEnd();
   }
-
-  if(c.flags & (CELL_ICE|CELL_ACID|CELL_SAND|CELL_TRACK)) {
-	glMaterialf(GL_FRONT,GL_SHININESS,0.0);
-	glDisable(GL_TEXTURE_2D);
-  } else if (c.texture >= 0)  {
-	glMaterialf(GL_FRONT,GL_SHININESS,0.0);
-	glDisable(GL_TEXTURE_2D);
-  }
+  glDisable(GL_TEXTURE_2D);
+  glMaterialf(GL_FRONT,GL_SHININESS,0.0);
   
+  /*** Draw the lines around this cell */
+  if(stage == 0 && !(c.flags & CELL_NOGRID)) {
+	glPolygonMode(GL_FRONT,GL_LINE);
+	GLfloat gridColor[4] = {0.0,0.0,0.0,0.8};
+	glMaterialfv(GL_FRONT,GL_AMBIENT_AND_DIFFUSE,gridColor);
+	glNormal3f(0.0,0.0,1.0);
+	/* Use polygon offset to avoid stippling of the lines */
+	glEnable(GL_POLYGON_OFFSET_LINE);
+	glPolygonOffset(-1.0, -1.0);
+	
+	if(0 && Settings::settings->gfx_details >= 4) {
+	  /* SORRY - no antialiasing for now! We have to draw the cells in two passes for this and I don't want to that for efficiency now (two display lists!) */
+	  glEnable(GL_BLEND);
+	  glEnable(GL_LINE_SMOOTH);
+	  glHint(GL_LINE_SMOOTH_HINT,GL_NICEST);
+	  glLineWidth(1.0);
+	  if (Settings::settings->gfx_details >= 5) {
+		/* TODO. Should we realy use polygon smooth here? */
+		glEnable(GL_POLYGON_SMOOTH);
+	  }
+	} else {
+	  glDisable(GL_BLEND);
+	  glDisable(GL_LINE_SMOOTH);
+	  glLineWidth(1.0);
+	}
+
+	glBegin(GL_QUADS); 
+	if(c.flags & CELL_NOLINESOUTH) glEdgeFlag(GL_FALSE);
+	else glEdgeFlag(GL_TRUE);
+	glVertex3f(x,y,c.heights[Cell::SOUTH+Cell::WEST]);
+	if(c.flags & CELL_NOLINEEAST) glEdgeFlag(GL_FALSE);
+	else glEdgeFlag(GL_TRUE);
+	glVertex3f(x+1.01,y,c.heights[Cell::SOUTH+Cell::EAST]);
+	if(c.flags & CELL_NOLINENORTH) glEdgeFlag(GL_FALSE);
+	else glEdgeFlag(GL_TRUE);
+	glVertex3f(x+1.01,y+1.01,c.heights[Cell::NORTH+Cell::EAST]);
+	if(c.flags & CELL_NOLINEWEST) glEdgeFlag(GL_FALSE);
+	else glEdgeFlag(GL_TRUE);
+	glVertex3f(x,y+1.01,c.heights[Cell::NORTH+Cell::WEST]);
+	glEnd();
+
+	glDisable(GL_POLYGON_OFFSET_LINE);
+	glDisable(GL_BLEND);
+	glPolygonMode(GL_FRONT,GL_FILL);
+  } 
+    
   /* Draw south side of cell */
   {
 	Cell& c2 = cell(x,y-1); draw=0;
@@ -791,9 +805,14 @@ void Map::drawCellAA(int birdsEye,int x,int y) {
 }
 
 
-/* Saves the map to file in compressed binary or compressed ascii format */
+/** Saves the map to file in compressed binary or compressed ascii format */
 int Map::save(char *pathname,int x,int y) {
   int i,version=mapFormatVersion;
+
+  if(pathIsLink(pathname)) {
+	fprintf(stderr,"Error, %s is a link, cannot save map\n",pathname);
+	return 0;
+  }
   
   gzFile gp = gzopen(pathname,"wb9");
   if(!gp) return 0;
