@@ -37,6 +37,8 @@
 
 class Cell {
  public:
+  /* Note. if you add fields here you must update the dump, load functions as well as editMode::pasteRegion */
+
   float velocity[2],heights[5];
   GLfloat colors[5][4];
   GLfloat wallColors[4][4];
@@ -45,6 +47,7 @@ class Cell {
   float textureCoords[4][2]; // Texture coordinates of corners. Center is average.
 
   int flags,texture;
+  int displayList, displayListLastCompiled, displayListDirty;
 
   void dump(gzFile gp);
   void load(class Map *map,gzFile gp,int version);
@@ -69,12 +72,11 @@ class Map {
   void draw(int birdseye,int stage,int x,int y);
   void drawCell(int birdsEye,int stage,int x,int y);
   void drawCellAA(int birdsEye,int x,int y);
-  void drawFootprint(int x,int y);
+  void drawFootprint(int x,int y,int kind);
   inline Real getHeight(Real x,Real y) {
 	int ix=(int) x;
 	int iy=(int) y;
-	Cell& c = cell(ix,iy);
-	return c.getHeight(x-ix,y-iy);
+	return cell(ix,iy).getHeight(x-ix,y-iy);
   }
   inline Real getWaterHeight(Real x,Real y) {
 	int ix=(int) x;
@@ -91,10 +93,7 @@ class Map {
   int indexTranslation[256]; // translates indices when reading map.
 
   int tx_Ice,tx_Acid,tx_Sand,tx_Track;
-
-
   Coord3d startPosition;
-  // int marked,markedLow[2],markedHigh[2]; // Can be used to highlight a region
 
   static const int flagNone,flagFlashCenter,flagTranslucent,flagShowCross;
   static const int mapFormatVersion;
@@ -104,6 +103,9 @@ class Map {
 
   int cachedCX, cachedCY, cacheCount;
   char cacheVisible[41][41];  
+
+  /* For maintaining display lists  */
+  int displayLists, nLists, nListsWide;
 };
 
 #endif
