@@ -233,7 +233,7 @@ void MenuMode::loadSlide() {
   snprintf(str,sizeof(str),"%s/images/slide-%02d.jpg",SHARE_DIR,(rand()%NUM_SLIDES)+1);
   slide=IMG_Load(str);
   if(!slide) {
-    printf(_("Error: Failed to load %s\n"),str); exit(0);
+    printf("Error: failed to load %s\n",str); exit(0);
   }
 
   /* Create a texture of it, and free the image data */
