@@ -36,6 +36,21 @@ class MenuMode : public GameMode {
  private:
   void doSelection();
   double offset;
+  double slideTime;
+
+  /** Moves old slide2 as new slide1 and loads a new random slide as
+      slide2 */
+  void loadSlide();
+  void drawSlide(int slide,double time);
+
+  /** The texture objects used for slide1/2 */
+  GLuint slides[2];
+
+  /** The texture coordinates limiting the slides */
+  GLfloat slideMin[2][2], slideMax[2][2];
+
+  /** What kind of movement is done on each slide */
+  int slideMode[2];
 };
 
 
