@@ -21,16 +21,20 @@
 #ifndef MENUSYSTEM_H
 #define MENUSYSTEM_H
 
+/* Primitive for creating anything selectable */
+void addArea(int code,int x,int y,int w,int h);
+
 /* Primitives for creating selectable text on screen */
 void clearSelectionAreas();
-void addText_Left(int code,int fontSize,int y0, char *left,int leftX);
-void addText_Center(int code,int fontSize,int y0, char *left,int cx);
-void addText_LeftRight(int code,int fontSize,int y0, char *leftStr,int leftX, char *rightStr,int rightX);
+void addText_Left(int code,int fontSize,int y0, const char *str,int leftX);
+void addText_Right(int code,int fontSize,int y0, const char *str,int rightX);
+void addText_Center(int code,int fontSize,int y0, const char *str,int cx);
+void addText_LeftRight(int code,int fontSize,int y0, const char *leftStr,int leftX, const char *rightStr,int rightX);
 int getSelectedArea();
 
 /* And for resolution independent centered menus */
-void menuItem_Left(int code,int row,char *str);
-void menuItem_Center(int code,int row,char *str);
-void menuItem_LeftRight(int code,int row,char *leftStr,char *rightStr);
+void menuItem_Left(int code,int row,const char *str);
+void menuItem_Center(int code,int row,const char *str);
+void menuItem_LeftRight(int code,int row,const char *leftStr,const char *rightStr);
 
 #endif
