@@ -27,6 +27,8 @@
 #include "sound.h"
 #include "mainMode.h"
 #include "settings.h"
+#include "debris.h"
+#include "sign.h"
 
 using namespace std;
 
@@ -35,6 +37,11 @@ using namespace std;
 
 int isGoodPill[NUM_MODS]={1,1,1,0,0,0,1,1};
 
+/* Explanations of modpills shown after taking them. Note that only bad 
+   ones have an exclamation mark after them */
+char *modExplanations[NUM_MODS] = {"Speed ball","Extra jump","Spikes","Glass ball","Dizzy!","Freeze!",
+								  "Floating","Extra life","Small ball","Large ball","Nitro"};
+
 ModPill::ModPill(Coord3d position,int kind,int time,int resurrecting)
   :Ball(), kind(kind), time(time), resurrecting(resurrecting), 
    state(STATE_ALIVE) {
@@ -87,7 +94,6 @@ void ModPill::tick(Real t) {
   Coord3d v;
   double dist;
 
-
   Player *player=Game::current->player1;
   if(state == STATE_DEAD) {
 	timeLeft -= t;
@@ -102,15 +108,40 @@ void ModPill::tick(Real t) {
   } else if(kind == MOD_SMALL) {
 	realRadius = 0.2 / (1.0 + fmod(clock,2.0) / 2.0);
 	radius=realRadius;
-	//printf("I'm a small mod pill, clock=%f, radius=%f\n",clock,radius);
   }
 
+  if(state == STATE_ALIVE && kind == MOD_NITRO) {
+	nitroDebrisCount += t;
+	while(nitroDebrisCount > 0.0) {
+	  nitroDebrisCount -= 0.25;
+	  Debris *d=new Debris(this,position,velocity,2.0+2.0*frandom());
+	  d->position[0] += (frandom()-0.5)*radius;
+	  d->position[1] += (frandom()-0.5)*radius;
+	  d->position[2] += radius*1.0;
+	  d->velocity[0] = 0.0;
+	  d->velocity[1] = 0.0;
+	  d->velocity[2] = 0.2;
+	  d->gravity=-0.1;
+	  d->modTimeLeft[MOD_GLASS]=-1.0;
+	  d->primaryColor[0]=0.1;
+	  d->primaryColor[1]=0.6;
+	  d->primaryColor[2]=0.1;
+	  d->no_physics=1;
+	}
+  }
+
+
   if(state == STATE_ALIVE) {	
 	position[2] = Game::current->map->getHeight(position[0],position[1]) + radius;
 	sub(player->position,position,v);
 	dist = length(v);
 	if(dist < radius + player->radius) {
 
+	  Coord3d signPos;
+	  assign(position,signPos);
+	  signPos[2] += 1.0;
+	  new Sign(modExplanations[kind],6.0,1.0,60.0,signPos);
+
 	  if(kind == MOD_EXTRA_LIFE) {
 		player->lives=min(4,player->lives+1);
 	  } else {
