@@ -30,6 +30,9 @@ class Pipe : public Animated {
   void draw();
   void draw2();
   void tick(Real t);
+  /** Recomputes the bounding box of the pipe. Needed after changes in from/to position */
+  void computeBoundingBox();
+  void onRemove();
 
   static void init();
   static void reset();
