@@ -63,7 +63,11 @@ Player::Player(Gamer *gamer) :Ball() {
 
   lastJoyX=lastJoyY=0;
   setReflectivity(0.4,0);
+
+  scoreOnDeath = Game::defaultScores[SCORE_PLAYER][0];
+  timeOnDeath = Game::defaultScores[SCORE_PLAYER][1];
 }
+
 Player::~Player() {
 }
 void Player::draw() {
@@ -75,6 +79,9 @@ void Player::tick(Real t) {
   int superAccelerate=0;
   static time_t lastTick=0;
 
+  /* Never let us drop below 0 points, it just looks silly */
+  if(score<0) score=0;
+
   if(!Game::current) return;
   if(!playing) return;
 
@@ -94,16 +101,19 @@ void Player::tick(Real t) {
     if(Settings::settings->sandbox == 0)
       die(DIE_TIMEOUT); 
     else {
+      /* DEPRACATED: This is instead handled by animated::die and the
+	 scoreOnDeath/timeOnDeath variables */
+      /*
       score -= 100;
       if(score < 0) score=0;
-      timeLeft += 60;
+      timeLeft += 60;*/
     }
     return; 
   }
 
   /* Check for oxygen by seeing if we are below water level. However:
-	 when we are in a pipe we might be below ground and thus below the water level even though 
-	 it's not supposed to be water here.
+     when we are in a pipe we might be below ground and thus below the water level even though 
+     it's not supposed to be water here.
   */
   if(map->getWaterHeight(position[0],position[1]) > position[2]+radius*0.75 &&
 	 (!(inPipe && position[2] < map->getHeight(position[0],position[1])))) {
@@ -272,8 +282,9 @@ void Player::jump() {
   } 	
 }
 void Player::die(int how) {
-  Map *map=Game::current->map;
+  Ball::die(how);
 
+  Map *map=Game::current->map;
   if(hasWon) return;
   if(!playing) return;
   if(Game::current->map->isBonus) {
