@@ -31,8 +31,9 @@ using namespace std;
    menu. The name of languages should appear in the respective native
    language. Eg. the Swedish language is written as 'Svenska'
 */
-char *Settings::languageCodes[5]={"","sv_SE","de_DE","it_IT","fr_FR"};
-char *Settings::languageNames[5]={"Default","Svenska","Deutsch","Italiano","Francais"};
+char *Settings::languageCodes[6]={"","sv_SE","de_DE","it_IT","fr_FR", "sk_SK"};
+//char *Settings::languageCodes[5]={"","sv","de","it","fr"};
+char *Settings::languageNames[6]={"Default","Svenska","Deutsch","Italiano","Francais" "Slovak"};
 int Settings::nLanguages=5;
 
 Settings *Settings::settings;
@@ -130,8 +131,8 @@ void Settings::loadLevelSets() {
 
 
   if(!nLevelSets) {
-	printf("Error: Failed to load any levelsets, place levels in %s/levels/",SHARE_DIR);
-	exit(0);
+    printf("Error: failed to load any levelsets, place levels in %s/levels/",SHARE_DIR);
+    exit(0);
   }
 }
 void Settings::loadLevelSet(char *setname) {
@@ -316,6 +317,7 @@ void Settings::setLocale() {
 
   /* check if the correct language directory exists, otherwise use default */
   if(language != 0) {
+
     char localedir[512];
 #ifdef LOCALEDIR
     snprintf(localedir,511,"%s/%c%c",LOCALEDIR,languageCodes[language][0],languageCodes[language][1]);
@@ -329,6 +331,9 @@ void Settings::setLocale() {
     }
   }
 
+
   /* Set the locale */
-  setlocale(LC_MESSAGES,languageCodes[language]);  
+  printf("setLocale: %s ",languageCodes[language]);
+  char *ret=setlocale(LC_MESSAGES,languageCodes[language]);  
+  printf("-> %s\n",ret);
 }
