@@ -47,21 +47,33 @@ class SettingsMode : public GameMode {
 	MENU_RETURN,
 
 	MENU_RESOLUTION,
+	MENU_APPLY_RESOLUTION,
 	MENU_WINDOWED,
 	MENU_GFX_DETAILS,
 	MENU_SHOW_FPS,
+	MENU_DO_REFLECTIONS,
 
+	MENU_USEMOUSE,
 	MENU_SENSITIVITY,
 	MENU_STEERING,
 	MENU_JOYSTICK,
 
 	MENU_MUSIC_VOLUME,
-	MENU_SFX_VOLUME,
+	MENU_SFX_VOLUME,	
+	MENU_LANGUAGE,
+
+	MENU_RESOLUTION_OK,
+	MENU_RESOLUTION_BAD,
 
   };
 
-  static SDL_Surface *title, *return2menu,*return2menuHigh;
+  //static SDL_Surface *title;
+  int resolution, colorDepth;        /* The resolution/depth displayed in the window */
+  int restoreResolution, restoreColorDepth; /* What the settings->res/depth will be set to when exiting */
   int selected;
+
+  double testingResolution;                 /* > 0 when we are testing a new resolution */
+
   enum eSubScreen subscreen;
 };
 
