@@ -22,6 +22,7 @@
 #include "animated.h"
 #include "splash.h"
 #include "glHelp.h"
+#include "settings.h"
 
 using namespace std;
 
@@ -47,6 +48,8 @@ void Splash::draw() {
 void Splash::draw2() {
   int i;
 
+  if(Settings::settings->gfx_details <= GFX_DETAILS_SIMPLE) return;
+
   glPushAttrib(GL_ENABLE_BIT);
   glEnable(GL_BLEND);
   glDisable(GL_LIGHTING);
